package com.ruoyi.doubledefense.service;

import java.util.List;

import com.ruoyi.common.core.domain.TreeSelect;
import com.ruoyi.doubledefense.domain.Contractor;
import com.ruoyi.doubledefense.domain.ContractorTreeSelect;
import com.ruoyi.doubledefense.dto.ContractorDTO;

/**
 * 承包商Service接口
 * 
 * @author ruoyi
 * @date 2023-08-04
 */
public interface IContractorService 
{
    /**
     * 查询承包商
     * 
     * @param id 承包商主键
     * @return 承包商
     */
    public ContractorDTO selectContractorById(String id);

    /**
     * 查询承包商列表
     * 
     * @param contractor 承包商
     * @return 承包商集合
     */
    public List<ContractorDTO> selectContractorList(ContractorDTO contractor);
    /**
     * 查询承包商tree并包含用户
     * @param isNeedUser 是否装载用户
     * @return
     */
    List<ContractorTreeSelect> selectContractorTreeListForApp(boolean isNeedUser);

    /**
     * 新增承包商
     * 
     * @param contractor 承包商
     * @return 结果
     */
    public int insertContractor(ContractorDTO contractor);

    /**
     * 修改承包商
     * 
     * @param contractor 承包商
     * @return 结果
     */
    public int updateContractor(ContractorDTO contractor);

    /**
     * 批量删除承包商
     * 
     * @param ids 需要删除的承包商主键集合
     * @return 结果
     */
    public int deleteContractorByIds(String[] ids);

}
